[−][src]Struct substrate_wasm_builder_runner::WasmBuilderSelectProject
First step of the WasmBuilder to select the project to build.
Methods
impl WasmBuilderSelectProject[src]
pub fn with_current_project(self) -> WasmBuilderSelectSource[src]
Use the current project as project for building the WASM binary.
Panics
Panics if the CARGO_MANIFEST_DIR variable is not set. This variable
is always set by Cargo in build.rs files.
pub fn with_project(
self,
path: impl Into<PathBuf>
) -> Result<WasmBuilderSelectSource, &'static str>[src]
self,
path: impl Into<PathBuf>
) -> Result<WasmBuilderSelectSource, &'static str>
Use the given path as project for building the WASM binary.
Returns an error if the given path does not points to a Cargo.toml.